@@ -19,7 +19,7 @@
 #include "umlwidgetstylepage.h"
 #include "codevieweroptionspage.h"
 #include "generaloptionpage.h"
-#include "dialog_utils.h"
+#include "dontaskagain.h"
 #include "debug_utils.h"
 #include "icon_utils.h"
 #include "layoutgenerator.h"
@@ -54,7 +54,9 @@ SettingsDialog::SettingsDialog(QWidget * parent, Settings::OptionState *state)
     m_bChangesApplied = false;
     m_pOptionState = state;
     setupGeneralPage();
-    setupFontPage();
+    m_dontAskAgainWidget = DontAskAgainHandler::instance().createWidget();
+    m_pGeneralPage->layout()->addWidget(m_dontAskAgainWidget);
+    pageFont = setupFontPage(state->uiState.font);
     setupUIPage();
     setupClassPage();
     setupCodeImportPage();
@@ -265,15 +267,6 @@ void SettingsDialog::setupCodeViewerPage(Settings::CodeViewerState options)
                                 Icon_Utils::it_Properties_CodeViewer, m_pCodeViewerPage);
 }
 
-void SettingsDialog::setupFontPage()
-{
-    m_FontWidgets.chooser = new KFontChooser(0, KFontChooser::NoDisplayFlags, QStringList(), 0);
-    m_FontWidgets.chooser->enableColumn(KFontChooser::StyleList, false);
-    m_FontWidgets.chooser->setFont(m_pOptionState->uiState.font);
-    pageFont = createPage(i18n("Font"), i18n("Font Settings"),
-                          Icon_Utils::it_Properties_Font, m_FontWidgets.chooser);
-}
-
 void SettingsDialog::setupAutoLayoutPage()
 {
     m_pAutoLayoutPage = new AutoLayoutOptionPage;
@@ -309,10 +302,11 @@ void SettingsDialog::slotDefault()
     if (current ==  pageGeneral)
     {
         m_pGeneralPage->setDefaults();
+        m_dontAskAgainWidget->setDefaults();
     }
     else if (current == pageFont)
     {
-        m_FontWidgets.chooser->setFont(parentWidget()->font());
+        resetFontPage(parentWidget());
     }
     else if (current == pageUserInterface)
     {
@@ -348,10 +342,11 @@ void SettingsDialog::applyPage(KPageWidgetItem*item)
     if (item == pageGeneral)
     {
         m_pGeneralPage->apply();
+        m_dontAskAgainWidget->apply();
     }
     else if (item == pageFont)
     {
-        m_pOptionState->uiState.font = m_FontWidgets.chooser->font();
+        applyFontPage(m_pOptionState);
     }
     else if (item == pageUserInterface)
     {
